Changelog
=========

1.0.0rc1 (2015-11-13)
---------------------

* Support recent psutil versions
  [ale-rt]

0.9.6 (2014-03-20)
------------------

* psutils 2 compatibility [ale-rt]

0.9.5 (2014-02-14)
------------------

* Python3 compatibility [ale-rt]

0.9.4 (2012-10-29)
------------------

* fixing a crash when zope.conf file is not found [ale-rt]
* handling help flags, fixes #1, fixes #2 [ale-rt]
* cosmetic fixes [ale-rt]

0.9.3 (2012/02/10)
------------------

* moved to github [ale-rt]
* heavy refactoring [ale-rt]
* added --grep flag [ale-rt]
* fix address calculations [ale-rt]
* sorting process list [ale-rt]
* tests [ale-rt]

0.9.2 (2010/06/10)
------------------

* Fixed documentation [keul]
* Fixed computing addresses in the form of ip:port [ale-rt]

0.9.1 (2010/06/10)
------------------

* Fixed egg structure [fdelia]
* pid option [ale-rt, fdelia]
* port option [ale-rt, fdelia]
* Refactoring [ale-rt]
* Documentation [ale-rt]

0.9.0 (2010/05/05)
------------------

* Initial release [ale-rt]
